Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/python/dandeliion/client/__init__.py | (no class) | 29 | 1 | 0 | 97%
src/python/dandeliion/client/exceptions.py | DandeliionInterfaceException | 0 | 0 | 0 | 100%
src/python/dandeliion/client/exceptions.py | DandeliionAPIException | 0 | 0 | 0 | 100%
src/python/dandeliion/client/exceptions.py | (no class) | 4 | 0 | 0 | 100%
src/python/dandeliion/client/simulator.py | Simulator | 36 | 2 | 0 | 94%
src/python/dandeliion/client/simulator.py | (no class) | 17 | 0 | 0 | 100%
src/python/dandeliion/client/solution.py | Simulator | 2 | 0 | 0 | 100%
src/python/dandeliion/client/solution.py | InterpolatedArray | 8 | 0 | 0 | 100%
src/python/dandeliion/client/solution.py | Solution | 24 | 1 | 0 | 96%
src/python/dandeliion/client/solution.py | (no class) | 22 | 0 | 0 | 100%
src/python/dandeliion/client/tools/misc.py | (no class) | 12 | 0 | 0 | 100%
src/python/dandeliion/client/websocket.py | SimulatorWebSocketClient | 20 | 1 | 0 | 95%
src/python/dandeliion/client/websocket.py | (no class) | 17 | 0 | 0 | 100%
Total |  | 191 | 5 | 0 | 97%

No items found using the specified filter.